# BacktestingEngine
MATLAB and Python scripts to fetch data from Coinbase and backtest an algorithm on the data. Start by running **main.m** or **main.py** then choose what you would like to do. You can test your own algorithm quickly by changing StratFile.m or StratFile.py to anything you'd like.
**This is Not Financial Advice**

=======================================================================================================

Backtester.m / Backtester.py output these charts/data (More analysis as well as an option to backtest on Brownian Motion will soon be added)

Python:

<img width="633" alt="img1" src="https://user-images.githubusercontent.com/107174743/185544629-16c11710-3dca-4fde-b27f-c9f6ca0401a9.png">
<img width="691" alt="img2" src="https://user-images.githubusercontent.com/107174743/185544633-e8483c97-b982-4732-9688-de114d218096.png">
<img width="911" alt="img3" src="https://user-images.githubusercontent.com/107174743/185544634-cef642e6-11e7-4dd3-9bad-2d55c8e8a972.png">
<img width="571" alt="img4" src="https://user-images.githubusercontent.com/107174743/185547078-9367ae4d-7218-479d-98f1-9e9d15837a38.png">

MATLAB:

<img width="633" alt="img5" src="https://user-images.githubusercontent.com/107174743/185547432-0fbdfcf8-ce92-4f83-a6ba-b61ed5851321.png">
<img width="633" alt="img6" src="https://user-images.githubusercontent.com/107174743/185547424-8da0ba6b-bc56-4f41-bb3d-c42858087be2.png">
<img width="933" alt="img8" src="https://user-images.githubusercontent.com/107174743/185548062-e4e063e8-0a41-43da-a1da-0e6dbbbfd1ba.png">
<img width="633" alt="img8" src="https://user-images.githubusercontent.com/107174743/185546652-9fa034e7-8ca9-424a-8db0-0de9a7d7011f.png">



